==> edjchain-1.0.3.tgz: package/interface/invoke.js <==
/*
 * SPDX-License-Identifier: Apache-2.0
 */

"use strict";

const { FileSystemWallet, Gateway } = require("fabric-network");
const path = require("path");

const ccpPath = path.resolve(
  __dirname,
  "..",
  "network",
  "connection-org1.json"
);

async function invoke(user, functionName, payload) {
  try {
    // Create a new file system based wallet for managing identities.
    const walletPath = path.join(process.cwd(), "wallet");
    const wallet = new FileSystemWallet(walletPath);

    // Check to see if we've already enrolled the user.
    const userExists = await wallet.exists(user);
    if (!userExists) {
      console.log(
        `An identity for the user ${user} does not exist in the wallet`
      );
      console.log("Run the registerUser.js application before retrying");
      return;
    }

    // Create a new gateway for connecting to our peer node.
    const gateway = new Gateway();
    await gateway.connect(ccpPath, {
      wallet,
      identity: user,
      discovery: { enabled: true, asLocalhost: true }
    });

    // Get the network (channel) our contract is deployed to.
    const network = await gateway.getNetwork("mychannel");

    // Get the contract from the network.
    const contract = network.getContract("edjx");

    // Submit the specified transaction.

    await contract.submitTransaction(functionName, JSON.stringify(payload));
    console.log("Transaction has been submitted");
    // Disconnect from the gateway.
    await gateway.disconnect();
  } catch (error) {
    console.error(`Failed to submit transaction: ${error}`);
    return error;
  }
}

// invoke("user2", "recordApplication", {
//   applicationId: "app29",
//   Name: "app29",
//   Status: "up"
// });

module.exports = invoke;

==> edjchain-1.0.12.tgz: package/interface/invoke.js <==
/*
 * SPDX-License-Identifier: Apache-2.0
 */

"use strict";

const { FileSystemWallet, Gateway } = require("fabric-network");
const path = require("path");

const ccpPath = path.resolve(
  __dirname,
  "..",
  "network",
  "connection-org1.json"
);

async function invoke(user, functionName, payload) {
  try {
    // Create a new file system based wallet for managing identities.
    const walletPath = path.join(__dirname, "..", "wallet");
    const wallet = new FileSystemWallet(walletPath);

    // Check to see if we've already enrolled the user.
    const userExists = await wallet.exists(user);
    if (!userExists) {
      console.log(
        `An identity for the user ${user} does not exist in the wallet`
      );
      console.log("Run the registerUser.js application before retrying");
      return;
    }

    // Create a new gateway for connecting to our peer node.
    const gateway = new Gateway();
    await gateway.connect(ccpPath, {
      wallet,
      identity: user,
      discovery: { enabled: true, asLocalhost: false }
    });

    // Get the network (channel) our contract is deployed to.
    const network = await gateway.getNetwork("mychannel");

    // Get the contract from the network.
    const contract = network.getContract("edjx");

    // Submit the specified transaction.

    await contract.submitTransaction(functionName, JSON.stringify(payload));
    console.log("Transaction has been submitted");
    // Disconnect from the gateway.
    await gateway.disconnect();
  } catch (error) {
    console.error(`Failed to submit transaction: ${error}`);
    return error;
  }
}

module.exports = invoke;
